==> jc-1.4.0.tar.gz: soot/jimple/spark/sets/P2SetFactory.c <==
// public abstract class soot.jimple.spark.sets.P2SetFactory

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class f801e5c664424a1 soot_Type
// @dep_class ebf774e64bb7347e soot_jimple_spark_pag_PAG
// @dep_class 4af9fec835f92d51 soot_jimple_spark_sets_P2SetFactory
// @dep_class bbf459c4685726ff soot_jimple_spark_sets_PointsToSetInternal

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_Type
// @dep_header soot_jimple_spark_pag_PAG
// @dep_header soot_jimple_spark_sets_P2SetFactory
// @dep_header soot_jimple_spark_sets_PointsToSetInternal

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/Type.h"
#include "soot/jimple/spark/pag/PAG.h"
#include "soot/jimple/spark/sets/P2SetFactory.h"
#include "soot/jimple/spark/sets/PointsToSetInternal.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_soot_jimple_spark_sets_P2SetFactory$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_jimple_spark_sets_P2SetFactory$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_jimple_spark_sets_P2SetFactory$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_jimple_spark_sets_P2SetFactory$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_jimple_spark_sets_P2SetFactory$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_spark_sets_P2SetFactory$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_spark_sets_P2SetFactory$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_spark_sets_P2SetFactory, _init$52f4ad9f2989aeee);

void
_jc_soot_jimple_spark_sets_P2SetFactory$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_jimple_spark_sets_P2SetFactory$object *this)
{
	struct _jc_soot_jimple_spark_sets_P2SetFactory$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(28);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract soot.jimple.spark.sets.PointsToSetInternal newSet(soot.Type, soot.jimple.spark.pag.PAG)
//

static const unsigned char _jc_soot_jimple_spark_sets_P2SetFactory$param_ptypes$newSet$774f6a02bfa5ba98[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_soot_jimple_spark_sets_P2SetFactory$param_types$newSet$774f6a02bfa5ba98[] = {
	&_jc_soot_Type$type,
	&_jc_soot_jimple_spark_pag_PAG$type
};

_jc_method _jc_soot_jimple_spark_sets_P2SetFactory$method_info$newSet$774f6a02bfa5ba98 = {
	.name=			"newSet",
	.signature=		"(Lsoot/Type;Lsoot/jimple/spark/pag/PAG;)Lsoot/jimple/spark/sets/PointsToSetInternal;",
	.class=			&_jc_soot_jimple_spark_sets_P2SetFactory$type,
	.param_types=		&_jc_soot_jimple_spark_sets_P2SetFactory$param_types$newSet$774f6a02bfa5ba98,
	.return_type=		&_jc_soot_jimple_spark_sets_PointsToSetInternal$type,
	.param_ptypes=		&_jc_soot_jimple_spark_sets_P2SetFactory$param_ptypes$newSet$774f6a02bfa5ba98,
	.signature_hash=	_JC_JLONG(0x774f6a02bfa5ba98),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_soot_jimple_spark_sets_P2SetFactory$method$newSet$774f6a02bfa5ba98,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_jimple_spark_sets_P2SetFactory$vtable, soot_jimple_spark_sets_P2SetFactory.newSet$774f6a02bfa5ba98) / sizeof(void *),
	.num_parameters=	2,
};

_jc_soot_jimple_spark_sets_PointsToSetInternal$object *
_jc_soot_jimple_spark_sets_P2SetFactory$method$newSet$774f6a02bfa5ba98(_jc_env *const env, _jc_soot_jimple_spark_sets_P2SetFactory$object *this, _jc_soot_Type$object *param0, _jc_soot_jimple_spark_pag_PAG$object *param1)
{
	_JC_ABSTRACT_METHOD(env, &_jc_soot_jimple_spark_sets_P2SetFactory$method_info$newSet$774f6a02bfa5ba98);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_jimple_spark_sets_P2SetFactory$methods[] = {
	&_jc_soot_jimple_spark_sets_P2SetFactory$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_jimple_spark_sets_P2SetFactory$method_info$newSet$774f6a02bfa5ba98
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_jimple_spark_sets_P2SetFactory$instanceof_hash_bucket_81[] = {
	&_jc_soot_jimple_spark_sets_P2SetFactory$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_spark_sets_P2SetFactory$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_jimple_spark_sets_P2SetFactory$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[81]=	_jc_soot_jimple_spark_sets_P2SetFactory$instanceof_hash_bucket_81,
	[113]=	_jc_soot_jimple_spark_sets_P2SetFactory$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_jimple_spark_sets_P2SetFactory$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "soot/Type",	_JC_JLONG(0xf801e5c664424a1) },
	{ "soot/jimple/spark/pag/PAG",	_JC_JLONG(0xebf774e64bb7347e) },
	{ "soot/jimple/spark/sets/PointsToSetInternal",	_JC_JLONG(0xbbf459c4685726ff) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_jimple_spark_sets_P2SetFactory$vtype _jc_soot_jimple_spark_sets_P2SetFactory$type = {
    .type= {
	.name=			"soot/jimple/spark/sets/P2SetFactory",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x4af9fec835f92d51),
		.source_file=		"P2SetFactory.java",
		.instance_size=		sizeof(_jc_soot_jimple_spark_sets_P2SetFactory$refs) + sizeof(_jc_soot_jimple_spark_sets_P2SetFactory$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_jimple_spark_sets_P2SetFactory$methods) / sizeof(*_jc_soot_jimple_spark_sets_P2SetFactory$methods),
		.methods=		_jc_soot_jimple_spark_sets_P2SetFactory$methods,
		.instanceof_hash_table=	_jc_soot_jimple_spark_sets_P2SetFactory$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_jimple_spark_sets_P2SetFactory$class_depends) / sizeof(*_jc_soot_jimple_spark_sets_P2SetFactory$class_depends),
		.class_depends=		_jc_soot_jimple_spark_sets_P2SetFactory$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_jimple_spark_sets_P2SetFactory= {
	    .newSet$774f6a02bfa5ba98=
		&_jc_soot_jimple_spark_sets_P2SetFactory$method$newSet$774f6a02bfa5ba98,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/jimple/spark/sets/P2SetFactory.c <==
// public abstract class soot.jimple.spark.sets.P2SetFactory

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class f801e5c664424a1 soot_Type
// @dep_class ebf774e64bb7347e soot_jimple_spark_pag_PAG
// @dep_class 4af9fec835f92d51 soot_jimple_spark_sets_P2SetFactory
// @dep_class bbf459c4685726ff soot_jimple_spark_sets_PointsToSetInternal

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_Type
// @dep_header soot_jimple_spark_pag_PAG
// @dep_header soot_jimple_spark_sets_P2SetFactory
// @dep_header soot_jimple_spark_sets_PointsToSetInternal

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/Type.h"
#include "soot/jimple/spark/pag/PAG.h"
#include "soot/jimple/spark/sets/P2SetFactory.h"
#include "soot/jimple/spark/sets/PointsToSetInternal.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_soot_jimple_spark_sets_P2SetFactory$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_jimple_spark_sets_P2SetFactory$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_jimple_spark_sets_P2SetFactory$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_jimple_spark_sets_P2SetFactory$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_jimple_spark_sets_P2SetFactory$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_spark_sets_P2SetFactory$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_spark_sets_P2SetFactory$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_spark_sets_P2SetFactory, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_soot_jimple_spark_sets_P2SetFactory$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_jimple_spark_sets_P2SetFactory$object *this)
{
	struct _jc_soot_jimple_spark_sets_P2SetFactory$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(28);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract soot.jimple.spark.sets.PointsToSetInternal newSet(soot.Type, soot.jimple.spark.pag.PAG)
//

static const unsigned char _jc_soot_jimple_spark_sets_P2SetFactory$param_ptypes$newSet$774f6a02bfa5ba98[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_soot_jimple_spark_sets_P2SetFactory$param_types$newSet$774f6a02bfa5ba98[] = {
	&_jc_soot_Type$type,
	&_jc_soot_jimple_spark_pag_PAG$type
};

_jc_method _jc_soot_jimple_spark_sets_P2SetFactory$method_info$newSet$774f6a02bfa5ba98 = {
	.name=			"newSet",
	.signature=		"(Lsoot/Type;Lsoot/jimple/spark/pag/PAG;)Lsoot/jimple/spark/sets/PointsToSetInternal;",
	.class=			&_jc_soot_jimple_spark_sets_P2SetFactory$type,
	.param_types=		&_jc_soot_jimple_spark_sets_P2SetFactory$param_types$newSet$774f6a02bfa5ba98,
	.return_type=		&_jc_soot_jimple_spark_sets_PointsToSetInternal$type,
	.param_ptypes=		&_jc_soot_jimple_spark_sets_P2SetFactory$param_ptypes$newSet$774f6a02bfa5ba98,
	.signature_hash=	_JC_JLONG(0x774f6a02bfa5ba98),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_soot_jimple_spark_sets_P2SetFactory$method$newSet$774f6a02bfa5ba98,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_jimple_spark_sets_P2SetFactory$vtable, soot_jimple_spark_sets_P2SetFactory.newSet$774f6a02bfa5ba98) / sizeof(void *),
	.num_parameters=	2,
};

_jc_soot_jimple_spark_sets_PointsToSetInternal$object * _JC_JCNI_ATTR
_jc_soot_jimple_spark_sets_P2SetFactory$method$newSet$774f6a02bfa5ba98(_jc_env *const env, _jc_soot_jimple_spark_sets_P2SetFactory$object *this, _jc_soot_Type$object *param0, _jc_soot_jimple_spark_pag_PAG$object *param1)
{
	_JC_ABSTRACT_METHOD(env, &_jc_soot_jimple_spark_sets_P2SetFactory$method_info$newSet$774f6a02bfa5ba98);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_jimple_spark_sets_P2SetFactory$methods[] = {
	&_jc_soot_jimple_spark_sets_P2SetFactory$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_jimple_spark_sets_P2SetFactory$method_info$newSet$774f6a02bfa5ba98
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_jimple_spark_sets_P2SetFactory$instanceof_hash_bucket_81[] = {
	&_jc_soot_jimple_spark_sets_P2SetFactory$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_spark_sets_P2SetFactory$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_jimple_spark_sets_P2SetFactory$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[81]=	_jc_soot_jimple_spark_sets_P2SetFactory$instanceof_hash_bucket_81,
	[101]=	_jc_soot_jimple_spark_sets_P2SetFactory$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_jimple_spark_sets_P2SetFactory$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "soot/Type",	_JC_JLONG(0xf801e5c664424a1) },
	{ "soot/jimple/spark/pag/PAG",	_JC_JLONG(0xebf774e64bb7347e) },
	{ "soot/jimple/spark/sets/PointsToSetInternal",	_JC_JLONG(0xbbf459c4685726ff) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_jimple_spark_sets_P2SetFactory$vtype _jc_soot_jimple_spark_sets_P2SetFactory$type = {
    .type= {
	.name=			"soot/jimple/spark/sets/P2SetFactory",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x4af9fec835f92d51),
		.source_file=		"P2SetFactory.java",
		.instance_size=		sizeof(_jc_soot_jimple_spark_sets_P2SetFactory$refs) + sizeof(_jc_soot_jimple_spark_sets_P2SetFactory$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_jimple_spark_sets_P2SetFactory$methods) / sizeof(*_jc_soot_jimple_spark_sets_P2SetFactory$methods),
		.methods=		_jc_soot_jimple_spark_sets_P2SetFactory$methods,
		.instanceof_hash_table=	_jc_soot_jimple_spark_sets_P2SetFactory$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_jimple_spark_sets_P2SetFactory$class_depends) / sizeof(*_jc_soot_jimple_spark_sets_P2SetFactory$class_depends),
		.class_depends=		_jc_soot_jimple_spark_sets_P2SetFactory$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_jimple_spark_sets_P2SetFactory= {
	    .newSet$774f6a02bfa5ba98=
		&_jc_soot_jimple_spark_sets_P2SetFactory$method$newSet$774f6a02bfa5ba98,
	},
    }
};
